@@ -3,7 +3,7 @@ from pathlib import Path
 from typing import Any, Optional
 
 import yaml
-from pydantic import BaseSettings
+from pydantic import BaseSettings, Field
 
 logger = logging.getLogger(__name__)
 
@@ -21,10 +21,15 @@ class LoggingConfig(BaseSettings):
     level: str = "INFO"
 
 
+class MonitoringConfig(BaseSettings):
+    check_every_secs: int = 60
+
+
 class Config(BaseSettings):
-    logging: LoggingConfig
-    database: DatabaseConfig
-    telegram: Optional[TelegramConfig]
+    logging: LoggingConfig = Field(default_factory=LoggingConfig)
+    database: DatabaseConfig = Field(default_factory=DatabaseConfig)
+    telegram: Optional[TelegramConfig] = Field(None)
+    monitoring: MonitoringConfig = Field(default_factory=MonitoringConfig)
 
 
 class ConfigReadFailed(RuntimeError):
